@@ -1,10 +1,10 @@
 /* Reentrant time functions like localtime_r.
 
-   Copyright (C) 2003, 2006 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2006-2007, 2010 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 2.1, or (at your option)
+   the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -20,9 +20,7 @@
 
 #include <config.h>
 
-#include "time_r.h"
-
-#include <string.h>
+#include <time.h>
 
 static struct tm *
 copy_tm_result (struct tm *dest, struct tm const *src)
