@@ -31,7 +31,7 @@ int manager_auth_disable_encryption(server_generic_client_t *client, prelude_io_
 
 int manager_auth_client(server_generic_client_t *client, prelude_io_t *pio, gnutls_alert_description *alert);
 
-int manager_auth_init(prelude_client_t *client, int dh_bits, int dh_regenerate);
+int manager_auth_init(prelude_client_t *client, const char *tlsopts, int dh_bits, int dh_regenerate);
 
 
 #endif /* _MANAGER_TLS_AUTH_H */
